@@ -4,29 +4,11 @@
 # for performance reasons, so turn off the lint warning
 # pylint: disable=import-outside-toplevel
 
-import os
+# We need to inject truststore code before we do any libraries
+# that might end up creating an ssl.SSlContext object
+# pylint: disable=wrong-import-position
+
 import sys
-from functools import wraps
-from typing import Optional
-
-import click
-import pkg_resources
-import requests
-from autoupgrade import Package
-from click.exceptions import ClickException
-
-from suite_py.__version__ import __version__
-from suite_py.commands.context import Context
-from suite_py.lib import logger, metrics
-from suite_py.lib.config import Config
-from suite_py.lib.handler import git_handler as git
-from suite_py.lib.handler import prompt_utils
-from suite_py.lib.handler.captainhook_handler import CaptainHook
-from suite_py.lib.handler.okta_handler import Okta
-from suite_py.lib.tokens import Tokens
-
-ALLOW_NO_GIT_SUBCOMMAND = ["login", "aggregator"]
-ALLOW_NO_HOME_SUBCOMMAND = ["login", "aggregator"]
 
 
 def maybe_inject_truststore() -> None:
@@ -38,20 +20,52 @@ def maybe_inject_truststore() -> None:
 
         truststore.inject_into_ssl()
     else:
+        # pylint: disable-next=reimported
+        from suite_py.lib import logger
+
         logger.warning(
             "Your python version is older than 3.10 and doesn't support the truststore package. You might experience issues with certificate verification when connected to the warp VPN.\nPlease update to python 3.10 or newer"
         )
 
 
-def fetch_latest_version() -> Optional[pkg_resources.packaging.version.Version]:
+# Needs to be done before any other imports
+maybe_inject_truststore()
+
+import os
+from functools import wraps
+from importlib.metadata import PackageNotFoundError, version
+from typing import Optional
+
+import click
+import requests
+from click.exceptions import ClickException
+
+from suite_py.__version__ import __version__
+from suite_py.commands.context import Context
+from suite_py.lib import logger, metrics
+from suite_py.lib.config import Config
+from suite_py.lib.handler import git_handler as git
+from suite_py.lib.handler import prompt_utils
+from suite_py.lib.handler.captainhook_handler import CaptainHook
+from suite_py.lib.handler.okta_handler import Okta
+from suite_py.lib.handler.pre_commit_handler import PreCommit
+from suite_py.lib.tokens import Tokens
+
+# pylint: enable=wrong-import-position
+
+ALLOW_NO_GIT_SUBCOMMAND = ["check", "set-token", "login"]
+ALLOW_NO_HOME_SUBCOMMAND = ["check", "set-token", "login"]
+
+
+def fetch_latest_version() -> Optional[str]:
     """
-    Fetches the latest version of suite-py as a pkg_resources parsed version
+    Fetches the latest version of suite-py as a str
     Returns None on error
     """
     try:
         # pylint: disable-next=missing-timeout
         pkg_info = requests.get("https://pypi.org/pypi/suite-py/json").json()
-        return pkg_resources.parse_version(pkg_info["info"]["version"])
+        return pkg_info["info"]["version"]
     except Exception:
         logger.warning("Failed to fetch latest version of suite-py!")
         return None
@@ -65,8 +79,8 @@ def upgrade_suite_py_if_needed(break_on_missing_package: bool = False) -> None:
     """
 
     try:
-        pkg_resources.get_distribution("suite_py")
-    except pkg_resources.DistributionNotFound as error:
+        installed_version = version("suite_py")
+    except PackageNotFoundError as error:
         # We are in a virtual environment where suite-py is not installed, don't bother trying to upgrade
         if break_on_missing_package:
             raise error
@@ -76,12 +90,12 @@ def upgrade_suite_py_if_needed(break_on_missing_package: bool = False) -> None:
         )
         return
 
-    current_version = pkg_resources.parse_version(__version__)
-
     try:
         # If available, upgrade (if needed)
         latest_version = fetch_latest_version()
-        if latest_version is None or latest_version > current_version:
+        if latest_version is None or latest_version > installed_version:
+            from autoupgrade import Package
+
             # If we fail to fetch the latest version, fallback to attempting the upgrade anyway
             Package("suite_py").upgrade()
     except Exception as error:
@@ -95,9 +109,11 @@ def catch_exceptions(func):
     def wrapper(*args, **kwargs):
         try:
             return func(*args, **kwargs)
-        except ClickException as e:
-            raise e
         except Exception as e:
+            # Ignore all exception classes from the click module
+            if type(e).__module__.startswith("click."):
+                raise e
+
             logger.debug("An error occured:", exc_info=True)
             raise ClickException(f"{str(e)}. rerun with -v for more details") from e
 
@@ -134,12 +150,12 @@ def main(ctx, project, timeout, verbose):
     if ctx.invoked_subcommand not in ALLOW_NO_GIT_SUBCOMMAND and not git.is_repo(
         project
     ):
-        raise Exception(f"the folder {project} is not a git repo")
+        raise ClickException(f"the folder {project} is not a git repo")
 
     if ctx.invoked_subcommand not in ALLOW_NO_HOME_SUBCOMMAND and not os.path.basename(
         project
     ) in os.listdir(config.user["projects_home"]):
-        raise Exception(
+        raise ClickException(
             f"the folder {project} is not in {config.user['projects_home']}"
         )
 
@@ -156,7 +172,7 @@ def main(ctx, project, timeout, verbose):
     if not skip_confirmation and not prompt_utils.ask_confirm(
         f"Do you want to continue on project {os.path.basename(project)}?"
     ):
-        return
+        ctx.exit()
     if timeout:
         config.user["captainhook_timeout"] = timeout
 
@@ -181,6 +197,9 @@ def main(ctx, project, timeout, verbose):
         or ctx.invoked_subcommand not in ALLOW_NO_HOME_SUBCOMMAND
     ):
         os.chdir(os.path.join(config.user["projects_home"], ctx.obj.project))
+    # Warn on missing pre_commit hook
+    if ctx.invoked_subcommand not in ALLOW_NO_GIT_SUBCOMMAND:
+        ctx.obj.call(PreCommit).check_and_warn()
 
 
 @main.result_callback()
@@ -245,8 +264,8 @@ def cli_unlock_project(obj, environment):
 @click.pass_obj
 @catch_exceptions
 def cli_open_pr(obj):
-    from suite_py.commands.open_pr import OpenPR
     from suite_py.commands.ask_review import AskReview
+    from suite_py.commands.open_pr import OpenPR
 
     ask_review = obj.call(AskReview)
     obj.call(OpenPR, ask_review=ask_review).run()
@@ -280,67 +299,12 @@ def release():
 @release.command(
     "create", help="Create a github release (and deploy it if GHA are used)"
 )
-@click.option(
-    "--deploy",
-    is_flag=True,
-    help="Trigger deploy with Drone CI after release creation (Github Actions based microservices will be automatically deployed on production)",
-)
 @click.pass_obj
 @catch_exceptions
-def cli_release_create(obj, deploy):
+def cli_release_create(obj):
     from suite_py.commands.release import Release
 
-    obj.call(Release, action="create", flags={"deploy": deploy}).run()
-
-
-@release.command("deploy", help="Deploy a github release with Drone CI")
-@click.pass_obj
-@catch_exceptions
-def cli_release_deploy(obj):
-    from suite_py.commands.release import Release
-
-    obj.call(Release, action="deploy").run()
-
-
-@release.command("rollback", help="Rollback a deployment")
-@click.pass_obj
-@catch_exceptions
-def cli_release_rollback(obj):
-    from suite_py.commands.release import Release
-
-    obj.call(Release, "rollback").run()
-
-
-@main.command("deploy", help="Deploy master branch in production")
-@click.pass_obj
-@catch_exceptions
-def cli_deploy(obj):
-    from suite_py.commands.deploy import Deploy
-
-    obj.call(Deploy).run()
-
-
-@main.group("docker", help="Manage docker images")
-def docker():
-    pass
-
-
-@docker.command("release", help="Release new docker image")
-@click.pass_obj
-@catch_exceptions
-def cli_docker_release(obj):
-    from suite_py.commands.docker import Docker
-
-    obj.call(Docker, action="release").run()
-
-
-@docker.command("versions", help="List all available versions of specific image")
-@click.pass_obj
-@catch_exceptions
-def cli_docker_versions(obj):
-    from suite_py.commands.docker import Docker
-
-    obj.call(Docker, action="versions").run()
+    obj.call(Release, action="create").run()
 
 
 @main.command("status", help="Current status of a project")
@@ -361,75 +325,6 @@ def cli_check(obj):
     obj.call(Check).run()
 
 
-@main.command("id", help="Get the ID of the hosts where the task is running")
-@click.argument("environment", type=click.Choice(("staging", "production")))
-@click.pass_obj
-@catch_exceptions
-def cli_id(obj, environment):
-    from suite_py.commands.id import ID
-
-    obj.call(ID, environment=environment).run()
-
-
-@main.command("ip", help="Get the IP addresses of the hosts where the task is running")
-@click.argument("environment", type=click.Choice(("staging", "production")))
-@click.pass_obj
-@catch_exceptions
-def cli_ip(obj, environment):
-    from suite_py.commands.ip import IP
-
-    obj.call(IP, environment=environment).run()
-
-
-@main.command("generator", help="Generate different files from templates")
-@click.pass_obj
-@catch_exceptions
-def cli_generator(obj):
-    from suite_py.commands.generator import Generator
-
-    obj.call(Generator).run()
-
-
-@main.group(
-    "aggregator",
-    help="Manage CNAMEs of aggregators in QA envs",
-    invoke_without_command=True,
-)
-@click.option(
-    "-l", "--list", "show_list", help="deprecated", required=False, count=True
-)
-@click.option("-c", "--change", "change", help="deprecated", required=False, count=True)
-@click.pass_context
-def aggregator(ctx, show_list, change):
-    if show_list == 1 or change == 1:
-        logger.error(
-            "suite-py aggregator [-c|-l] has been hard-deprecated. Use suite-py aggregator [list|change] instead."
-        )
-        sys.exit(0)
-
-    if ctx.invoked_subcommand is None:
-        logger.error("Missing command. Try suite-py aggregator --help for help.")
-        sys.exit(0)
-
-
-@aggregator.command("list", help="List all aggregators with the current record")
-@click.pass_obj
-@catch_exceptions
-def cli_aggregator_list(obj):
-    from suite_py.commands.aggregator import Aggregator
-
-    obj.call(Aggregator, action="list").run()
-
-
-@aggregator.command("change", help="Change aggregator record")
-@click.pass_obj
-@catch_exceptions
-def cli_aggregator_change(obj):
-    from suite_py.commands.aggregator import Aggregator
-
-    obj.call(Aggregator, action="list").run()
-
-
 @main.command("login", help="manage login against Auth0")
 @click.pass_obj
 @catch_exceptions
@@ -439,70 +334,6 @@ def login(obj):
     obj.call(Login).run()
 
 
-@main.group(
-    "secret", help="Manage secrets grants in multiple countries (aws-vault needed)"
-)
-def secret():
-    pass
-
-
-@secret.command("create", help="Create a new secret")
-@click.option("-b", "--base-profile", "base_profile", required=False)
-@click.option("-f", "--secret-file", "secret_file", required=False)
-@click.pass_obj
-@catch_exceptions
-def cli_secret_create(obj, base_profile, secret_file):
-    from suite_py.commands.secret import Secret
-
-    obj.call(
-        Secret, action="create", base_profile=base_profile, secret_file=secret_file
-    ).run()
-
-
-@secret.command("grant", help="Grant permissions to an existing secret")
-@click.option("-b", "--base-profile", "base_profile", required=False)
-@click.option("-f", "--secret-file", "secret_file", required=False)
-@click.pass_obj
-@catch_exceptions
-def cli_secret_grant(obj, base_profile, secret_file):
-    from suite_py.commands.secret import Secret
-
-    obj.call(
-        Secret, action="grant", base_profile=base_profile, secret_file=secret_file
-    ).run()
-
-
-@main.command("batch-job", help="Run batch job on kube")
-@click.argument("environment", type=click.Choice(("staging", "production")))
-@click.option(
-    "-c",
-    "--cpu",
-    "cpu_request",
-    required=True,
-    type=str,
-    help="Millicpu format. E.g: 1000m (=1CPU)",
-)
-@click.option(
-    "-m",
-    "--memory",
-    "memory_request",
-    required=True,
-    type=str,
-    help="Mebibytes or gibibyte format. E.g: 256Mi or 1Gi",
-)
-@click.pass_obj
-@catch_exceptions
-def cli_run_batch_job(obj, environment, cpu_request, memory_request):
-    from suite_py.commands.batch_job import BatchJob
-
-    obj.call(
-        BatchJob,
-        environment=environment,
-        cpu_request=cpu_request,
-        memory_request=memory_request,
-    ).run()
-
-
 @main.command("set-token", help="Create or update a service token")
 @click.pass_obj
 @catch_exceptions
