@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
 import sys
 
-from suite_py.lib import logger
-from suite_py.lib import metrics
-from suite_py.lib.handler.captainhook_handler import CaptainHook
+from suite_py.lib import logger, metrics
 from suite_py.lib.handler.frequent_reviewers_handler import FrequentReviewersHandler
 from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.github_handler import GithubHandler
@@ -12,11 +10,11 @@ from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 
 
 class AskReview:
-    def __init__(self, project, config, tokens):
+    def __init__(self, project, captainhook, config, tokens):
         self._project = project
         self._config = config
         self._youtrack = YoutrackHandler(config, tokens)
-        self._captainhook = CaptainHook(config)
+        self._captainhook = captainhook
         self._git = GitHandler(project, config)
         self._github = GithubHandler(tokens)
         self._frequent_reviewers = FrequentReviewersHandler(config)
