@@ -4,8 +4,7 @@ import sys
 
 import requests
 
-from suite_py.lib import logger
-from suite_py.lib import metrics
+from suite_py.lib import logger, metrics
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.git_handler import GitHandler, is_branch_name_valid
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
