@@ -269,6 +269,45 @@ class GitHandler:
             logger.error(f"Error during git reset on {self._repo}: {e}")
             sys.exit(-1)
 
+    def get_git_config(self, option):
+        """
+        Get git config value.
+        Git configs are very versitile and allow arbitrary string KV pairs to be stored,
+        support per-repo, or more complex conditional and global configurations,
+        making it the perfect place for us to store a lot of our configs.
+        """
+        proc = subprocess.run(
+            ["git", "config", "get", option],
+            cwd=self._path,
+            check=False,
+            capture_output=True,
+        )
+        if proc.returncode == 0:
+            return proc.stdout.decode().strip()
+        return None
+
+    def hooks_path(self):
+        """
+        Get path to git-hooks
+        See: https://git-scm.com/book/en/v2/Customizing-Git-Git-Hooks for more details
+        """
+        try:
+            proc = subprocess.run(
+                ["git", "rev-parse", "--git-path", "hooks"],
+                cwd=self._path,
+                check=True,
+                capture_output=True,
+            )
+            hooks = proc.stdout.decode().strip()
+
+            # Return absolute path to the hooks dir,
+            # since we overwrite the subprocesses cwd.
+            abs_path = os.path.join(self._path, hooks)
+            return abs_path
+        except CalledProcessError as e:
+            logger.error(f"Error getting hooks path {self._repo}: {e}")
+            sys.exit(-1)
+
 
 def get_root_folder(directory):
     return (
